unit uMySplitView;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants,
  System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.ExtCtrls, Vcl.StdCtrls,
  Vcl.WinXCtrls, Vcl.CategoryButtons, System.ImageList, Vcl.ImgList,
  Vcl.Imaging.pngimage, System.Actions, Vcl.ActnList, uStudent, uTeacher;

type
  TMySplitView = class(TForm)
    pnl: TPanel;
    SV: TSplitView;
    pnl_menu: TPanel;
    img_menuHome: TImage;
    ilIcons: TImageList;
    catMenuItems: TCategoryButtons;
    ActionList1: TActionList;
    actHome: TAction;
    lbl1: TLabel;
    lblLog: TLabel;
    lstLog: TListBox;
    actStudent: TAction;
    actTeacher: TAction;
    actStudentClose: TAction;
    btn_pnlEmpty: TButton;
    actTeacherClose: TAction;
    procedure actHomeExecute(Sender: TObject);
    procedure catMenuItemsCategoryCollapase(Sender: TObject;
      const Category: TButtonCategory);
    procedure img_menuHomeClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure SVOpening(Sender: TObject);
    procedure SVOpened(Sender: TObject);
    procedure SVClosed(Sender: TObject);
    procedure actStudentExecute(Sender: TObject);
    procedure actTeacherExecute(Sender: TObject);
    procedure actStudentCloseExecute(Sender: TObject);
    procedure actTeacherCloseExecute(Sender: TObject);
  private
    { Private declarations }
    procedure Log(const Msg: string);
  public
    { Public declarations }
    splitViewDebug: string;
  end;

var
  MySplitView: TMySplitView;
  Student: TStudent;
  Teacher: TTeacher;

implementation

{$R *.dfm}

procedure TMySplitView.actHomeExecute(Sender: TObject);
begin
  Log(actHome.Caption + ' Clicked');
  SV.Close;
end;

procedure TMySplitView.actStudentCloseExecute(Sender: TObject);
begin
  if (Student <> Nil) then
  FreeAndNil(Student);
end;

procedure TMySplitView.actStudentExecute(Sender: TObject);
begin
  if (Student <> Nil) or (Teacher <> Nil) then
    exit;
  Student := TStudent.Create(self);
  Student.Parent := pnl;
  Student.name := 'myStudent';
  Student.BorderStyle := bsNone;
  Student.Show();
end;

procedure TMySplitView.actTeacherCloseExecute(Sender: TObject);
begin
  if (Teacher <> Nil) then
    FreeAndNil(Teacher);
end;

procedure TMySplitView.actTeacherExecute(Sender: TObject);
begin
  if (Student <> Nil) or (Teacher <> Nil) then
    exit;
  Teacher := TTeacher.Create(self);
  Teacher.Parent := pnl;
  Teacher.name := 'myTeacher';
  Teacher.BorderStyle := bsNone;
  Teacher.Show();
end;

procedure TMySplitView.catMenuItemsCategoryCollapase(Sender: TObject;
  const Category: TButtonCategory);
begin
  // Prevent the catMenuItems Category group from being collapsed
  // catMenuItems.Categories[0].Collapsed := False;
end;

procedure TMySplitView.FormShow(Sender: TObject);
begin
  splitViewDebug := 'ma var spliView';
  SV.Close;
  // svcCollapse, svcCompact
  SV.CloseStyle := TSplitViewCloseStyle(svcCompact);
  // (svmDocked, svmOverlay);
  SV.DisplayMode := TSplitViewDisplayMode(svmOverlay);
end;

procedure TMySplitView.img_menuHomeClick(Sender: TObject);
begin
  if SV.Opened then
    SV.Close
  else
    SV.Open;
end;

procedure TMySplitView.Log(const Msg: string);
var
  Idx: Integer;
begin
  Idx := lstLog.Items.Add(Msg);
  lstLog.TopIndex := Idx;
end;

procedure TMySplitView.SVClosed(Sender: TObject);
begin
  // When TSplitView is closed, adjust ButtonOptions and Width
  catMenuItems.ButtonOptions := catMenuItems.ButtonOptions - [boShowCaptions];
  if SV.CloseStyle = svcCompact then
    catMenuItems.Width := SV.CompactWidth;
end;

procedure TMySplitView.SVOpened(Sender: TObject);
begin
  // When not animating, change size of catMenuItems when TSplitView is opened
  catMenuItems.ButtonOptions := catMenuItems.ButtonOptions + [boShowCaptions];
  catMenuItems.Width := SV.OpenedWidth;
end;

procedure TMySplitView.SVOpening(Sender: TObject);
begin
  // When animating, change size of catMenuItems at the beginning of open
  catMenuItems.ButtonOptions := catMenuItems.ButtonOptions + [boShowCaptions];
  catMenuItems.Width := SV.OpenedWidth;
end;

end.
